@@ -24,10 +24,10 @@ tools for BN analysis in jupyter notebook
 """
 from __future__ import print_function
 
+import base64
 import time
 
 import IPython.display
-import base64
 import matplotlib as mpl
 import matplotlib.pyplot as plt
 import numpy as np
@@ -37,8 +37,7 @@ from IPython.core.display import Image, display_png
 from IPython.core.pylabtools import print_figure
 from IPython.display import display, HTML, SVG
 from matplotlib.backends.backend_agg import FigureCanvasAgg as fc
-from pyAgrum.lib.bn2graph import BN2dot, proba2histo, BNinference2dot,_proba2bgcolor
-
+from pyAgrum.lib.bn2graph import BN2dot, proba2histo, BNinference2dot, _proba2bgcolor
 
 _cdict = {
   'red'  : ((0.0, 0.1, 0.3),
@@ -50,6 +49,7 @@ _cdict = {
 }
 _INFOcmap = mpl.colors.LinearSegmentedColormap('my_colormap', _cdict, 256)
 
+
 def configuration():
   """
   Display the collection of dependance and versions
@@ -144,7 +144,7 @@ def getDot(dotstring, size="4", format="png"):
   :param format: render as "png" or "svg"
   :return: the HTML representation of the graph
   """
-  g=dot.graph_from_dot_data(dotstring)
+  g = dot.graph_from_dot_data(dotstring)
   g.set_bgcolor("transparent")
   return getGraph(g, size, format)
 
@@ -285,6 +285,19 @@ def animApproximationScheme(apsc, scale=np.log10):
   h.setWhenProgress(progresser)
 
 
+def showApproximationScheme(apsc, scale=np.log10):
+  if apsc.verbosity():
+    if len(apsc.history()) < 10:
+      plt.xlim(1, 10)
+    else:
+      plt.xlim(1, len(apsc.history()))
+    plt.title("{0} \n Time : {1} s | Iterations : {2} | Espilon : {3}".format(x, apsc.currentTime(), apsc.nbrIterations(),
+                                                                              apsc.epsilon()))
+    plt.plot(scale(apsc.history()), 'g')
+  else:
+    ie2.messageApproximationScheme()
+
+
 def showBN(bn, size="4", format="svg", arcvals=None, vals=None, cmap=None):
   """
   show a Bayesian network
@@ -354,7 +367,7 @@ def _reprInformation(bn, evs, size, cmap, asString):
   ie.makeInference()
 
   idEvs = {bn.idFromName(name) for name in evs}
-  nodevals = {bn.variable(n).name(): ie.H(n) for n in bn.ids() if not n in idEvs}
+  nodevals = {bn.variable(n).name(): ie.H(n) for n in bn.nodes() if not n in idEvs}
   arcvals = {(x, y): ie.I(x, y) for x, y in bn.arcs()}
   gr = BN2dot(bn, size, arcvals, _normalizeVals(nodevals, hilightExtrema=False), cmap, showValues=nodevals)
 
@@ -543,8 +556,23 @@ def _reprPotential(pot, digits=4, withColors=True, varnames=None, asString=False
   else:
     return HTML("".join(html))
 
+def __isKindOfProba(pot):
+  """
+  check if pot is a joint proba or a CPT
+  :param pot: the potential
+  :return: True or False
+  """
+  if abs(pot.sum()-1)<1e-2:
+    return True
 
-def showPotential(pot, digits=4, withColors=True, varnames=None):
+  q=pot.margSumOut([pot.variable(0).name()])
+  if abs(q.max()-1)>1e-2:
+    return False
+  if abs(q.min()-1)>1e-2:
+    return False
+  return True
+
+def showPotential(pot, digits=4, withColors=None, varnames=None):
   """
   show a gum.Potential as a HTML table.
   The first dimension is special (horizontal) due to the representation of conditional probability table
@@ -555,10 +583,13 @@ def showPotential(pot, digits=4, withColors=True, varnames=None):
   :param list of strings varnames: the aliases for variables name in the table
   :return: the display of the potential
   """
+  if withColors is None:
+    withColors=__isKindOfProba
+
   display(_reprPotential(pot, digits, withColors, varnames, asString=False))
 
 
-def getPotential(pot, digits=4, withColors=True, varnames=None):
+def getPotential(pot, digits=4, withColors=None, varnames=None):
   """
   return a HTML string of a gum.Potential as a HTML table.
   The first dimension is special (horizontal) due to the representation of conditional probability table
@@ -569,6 +600,9 @@ def getPotential(pot, digits=4, withColors=True, varnames=None):
   :param list of strings varnames: the aliases for variables name in the table
   :return: the HTML string
   """
+  if withColors is None:
+    withColors=__isKindOfProba(pot)
+
   return _reprPotential(pot, digits, withColors, varnames, asString=True)
 
 
